.. _spkg_pyyaml:

pyyaml: YAML parser and emitter for Python
==========================================

Description
-----------

YAML parser and emitter for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/PyYAML/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`

Version Information
-------------------

package-version.txt::

    6.0.2

version_requirements.txt::

    PyYAML

Equivalent System Packages
--------------------------

(none known)
